@@ -52,11 +52,38 @@ sAppendN(&sbOut, "rxode2_fn0i _sumType=NULL;\n", 27);
 sAppendN(&sbOut, "_update_par_ptr_p _update_par_ptr=NULL;\n", 40);
 sAppendN(&sbOut, "_getParCov_p _getParCov=NULL;\n", 30);
 sAppendN(&sbOut, "linCmtA_p linCmtA;\n", 19);
-sAppendN(&sbOut, "linCmtA_p linCmtC;\n", 19);
 sAppendN(&sbOut, "linCmtB_p linCmtB;\n", 19);
 sAppendN(&sbOut, "_rx_asgn _rxode2_rxAssignPtr=NULL;\n", 35);
 sAppendN(&sbOut, "_rx_asgn _rxQr=NULL;\n", 21);
 sAppendN(&sbOut, "rxode2_fn phi;\n", 15);
+sAppendN(&sbOut, "rxode2_fn ReLU;\n", 16);
+sAppendN(&sbOut, "rxode2_fn dReLU;\n", 17);
+sAppendN(&sbOut, "rxode2_fn GELU;\n", 16);
+sAppendN(&sbOut, "rxode2_fn dGELU;\n", 17);
+sAppendN(&sbOut, "rxode2_fn d2GELU;\n", 18);
+sAppendN(&sbOut, "rxode2_fn d3GELU;\n", 18);
+sAppendN(&sbOut, "rxode2_fn d4GELU;\n", 18);
+sAppendN(&sbOut, "rxode2_fn softplus;\n", 20);
+sAppendN(&sbOut, "rxode2_fn dsoftplus;\n", 21);
+sAppendN(&sbOut, "rxode2_fn d2softplus;\n", 22);
+sAppendN(&sbOut, "rxode2_fn d3softplus;\n", 22);
+sAppendN(&sbOut, "rxode2_fn d4softplus;\n", 22);
+sAppendN(&sbOut, "rxode2_fn SELU;\n", 16);
+sAppendN(&sbOut, "rxode2_fn dSELU;\n", 17);
+sAppendN(&sbOut, "rxode2_fn lReLU;\n", 17);
+sAppendN(&sbOut, "rxode2_fn dlReLU;\n", 18);
+sAppendN(&sbOut, "rxode2_fn Swish;\n", 17);
+sAppendN(&sbOut, "rxode2_fn dSwish;\n", 18);
+sAppendN(&sbOut, "rxode2_fn2 PReLU;\n", 18);
+sAppendN(&sbOut, "rxode2_fn2 dPReLU;\n", 19);
+sAppendN(&sbOut, "rxode2_fn2 dPReLUa;\n", 20);
+sAppendN(&sbOut, "rxode2_fn2 dPReLUa1;\n", 21);
+sAppendN(&sbOut, "rxode2_fn2 ELU;\n", 16);
+sAppendN(&sbOut, "rxode2_fn2 dELU;\n", 17);
+sAppendN(&sbOut, "rxode2_fn2 d2ELU;\n", 18);
+sAppendN(&sbOut, "rxode2_fn2 d2aELU;\n", 19);
+sAppendN(&sbOut, "rxode2_fn2 dELUa;\n", 18);
+sAppendN(&sbOut, "rxode2_fn2 d2ELUa;\n", 19);
 sAppendN(&sbOut, "rxode2_fn3 logit;\n", 18);
 sAppendN(&sbOut, "rxode2_fn3 expit;\n", 18);
 sAppendN(&sbOut, "rxode2_fn2 gammap;\n", 19);
