@@ -1,9 +1,10 @@
 rxTest({
   test_that("mixing omega and sigma with parameter data frame; RxODE#375", {
+
     lognCv <- function(x) {
       log((x / 100)^2 + 1)
     }
-    
+
     mod2 <- rxode2({
       ## the order of variables do not matter, the type of compartmental
       ## model is determined by the parameters specified.
@@ -15,40 +16,39 @@ rxTest({
       resp <- eff + err1
       pk <- C2 * exp(err2)
     })
-    
-    
+
+
     ev <- eventTable(amount.units = "mg", time.units = "hours") %>%
       add.dosing(dose = 10000, nbr.doses = 10, dosing.interval = 12, dosing.to = 2) %>%
       add.dosing(dose = 20000, nbr.doses = 5, start.time = 120, dosing.interval = 24, dosing.to = 2) %>%
       add.sampling(0:240)
-    
+
     ## Add Residual differences
     sigma <- diag(2) * 0.05
     dimnames(sigma) <- list(c("err1", "err2"), c("err1", "err2"))
-    
+
     omega <- matrix(0.2, dimnames = list("eta.Cl", "eta.Cl"))
-    
+
     theta <- c(
       KA = 2.94E-01, TCL = 1.86E+01, V2 = 4.02E+01, Q = 1.05E+01, V3 = 2.97E+02,
       Kin = 1, Kout = 1, EC50 = 200
     )
-    
+
     thetaMat <- diag(length(theta)) * lognCv(5)
     dimnames(thetaMat) <- list(names(theta), names(theta))
-    
+
     nStud <- 3
-    
+
     nSub <- 12
-    
+
     par <- rxRmvn(nStud, theta, thetaMat)
-    
+
     par <- rxCbindStudyIndividual(par, data.frame(WT = rnorm(nStud * nSub, 70, 10)))
-    
+
     expect_error(rxSolve(mod2, ev, par,
                          omega = omega, sigma = sigma, dfSub = 100, dfObs = 400,
-                         nStud = nStud, nSub = nSub
-                         ), NA)
-    
+                         nStud = nStud, nSub = nSub), NA)
+
     # Nesting:
     ## mod <- rxode2({
     ##   ## Clearance with individuals
@@ -63,8 +63,8 @@ rxTest({
     ##   d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
     ##   ef0 = eff + add.sd
     ## })
-    
-    
+
+
     ## et(amountUnits="mg", timeUnits="hours") %>%
     ##   et(amt=10000, addl=9,ii=12,cmt="depot") %>%
     ##   et(time=120, amt=2000, addl=4, ii=14, cmt="depot") %>%
@@ -79,25 +79,25 @@ rxTest({
     ##   dplyr::mutate(inv=ifelse(id < 10, 1, 2)) %>%
     ##   dplyr::as_tibble() ->
     ##   ev
-    
-    
+
+
     ## theta <- c("TKA"=0.294, "TCl"=18.6, "V2"=40.2,
     ##            "Q"=10.5, "V3"=297, "Kin"=1, "Kout"=1, "EC50"=200)
-    
+
     ## ## Creating covariance matrix
     ## tmp <- matrix(rnorm(8^2), 8, 8)
     ## tMat <- tcrossprod(tmp, tmp) / (8 ^ 2)
     ## dimnames(tMat) <- list(names(theta), names(theta))
-    
+
     ## tMat
-    
+
     ## nStud <- 4
-    
+
     ## nSub <- 20
-    
+
     ## par <- rxCbindStudyIndividual(rxRmvn(nStud, theta, tMat),
     ##                               data.frame(WT=rnorm(nStud * nSub, 70, 10)))
-    
+
     ## omega <- lotri(lotri(eta.Cl ~ 0.1,
     ##                  eta.Ka ~ 0.1) | id(nu=100),
     ##            lotri(eye.Cl ~ 0.05,
@@ -106,11 +106,11 @@ rxTest({
     ##                  iov.Ka ~ 0.01) | occ(nu=200),
     ##            lotri(inv.Cl ~ 0.02,
     ##                  inv.Ka ~ 0.02) | inv(nu=10))
-    
-    
+
+
     ## sigma <- lotri(prop.sd ~ .25,
     ##            add.sd~ 0.125)
-    
+
     ## s <- rxSolve(mod, par, ev, omega=omega,
     ##              sigma=sigma, sigmaDf=400,
     ##              nStud=nStud)
